==> cabin-dev-server-1.1.21.tgz: package/lib/server.js <==
'use strict';

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var _asyncToGenerator2 = require('babel-runtime/helpers/asyncToGenerator');

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _createClass2 = require('babel-runtime/helpers/createClass');

var _createClass3 = _interopRequireDefault(_createClass2);

var _koa = require('koa');

var _koa2 = _interopRequireDefault(_koa);

var _index = require('./middle-ware/concat/index');

var _index2 = _interopRequireDefault(_index);

var _koa2Static = require('koa2-static');

var _koa2Static2 = _interopRequireDefault(_koa2Static);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var chalk = require('chalk');
var cors = require('koa2-cors');

var CabinDevServer = function () {
    function CabinDevServer(options) {
        (0, _classCallCheck3.default)(this, CabinDevServer);

        this.options = options;
        this.init();
        this.init.bind(this);
        this.start.bind(this);
        this.stop.bind(this);
    }

    (0, _createClass3.default)(CabinDevServer, [{
        key: 'init',
        value: function init() {
            var _this = this;

            this.app = new _koa2.default();
            var concat = new _index2.default({ 'staticPath': this.options.staticPath });
            this.app.use(cors({
                allowMethods: ['GET', 'POST'],
                origin: function origin(ctx) {
                    return '*';
                }
            }));
            this.app.use(concat.init);
            this.app.use((0, _koa2Static2.default)({
                'path': '',
                'root': this.options.staticPath + '/'
            }));
            this.app.use(function () {
                var _ref = (0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee(ctx) {
                    return _regenerator2.default.wrap(function _callee$(_context) {
                        while (1) {
                            switch (_context.prev = _context.next) {
                                case 0:
                                    ctx.body = 'resource not found';

                                case 1:
                                case 'end':
                                    return _context.stop();
                            }
                        }
                    }, _callee, _this);
                }));

                return function (_x) {
                    return _ref.apply(this, arguments);
                };
            }());
        }
    }, {
        key: 'start',
        value: function start() {
            this.app.listen(this.options.port);
            console.log(chalk.yellow('[cabin] server start at port:' + this.options.port));
        }
    }, {
        key: 'stop',
        value: function stop() {
            this.app.stop();
            console.log(chalk.yellow('[cabin] server stopped'));
        }
    }]);
    return CabinDevServer;
}();

exports.CabinDevServer = CabinDevServer;

==> cabin-dev-server-1.1.23.tgz: package/lib/server.js <==
'use strict';

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var _asyncToGenerator2 = require('babel-runtime/helpers/asyncToGenerator');

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _createClass2 = require('babel-runtime/helpers/createClass');

var _createClass3 = _interopRequireDefault(_createClass2);

var _koa = require('koa');

var _koa2 = _interopRequireDefault(_koa);

var _index = require('./middle-ware/concat/index');

var _index2 = _interopRequireDefault(_index);

var _koa2Static = require('koa2-static');

var _koa2Static2 = _interopRequireDefault(_koa2Static);

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

var _koa2Cors = require('koa2-cors');

var _koa2Cors2 = _interopRequireDefault(_koa2Cors);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var CabinDevServer = function () {
    function CabinDevServer(options) {
        (0, _classCallCheck3.default)(this, CabinDevServer);

        this.options = options;
        this.init();
        this.init.bind(this);
        this.start.bind(this);
        this.stop.bind(this);
    }

    (0, _createClass3.default)(CabinDevServer, [{
        key: 'init',
        value: function init() {
            var _this = this;

            this.app = new _koa2.default();
            var concat = new _index2.default({ 'staticPath': this.options.staticPath });
            this.app.use((0, _koa2Cors2.default)({
                allowMethods: ['GET', 'POST'],
                origin: function origin(ctx) {
                    return '*';
                }
            }));
            this.app.use(concat.init);
            this.app.use((0, _koa2Static2.default)({
                'path': '',
                'root': this.options.staticPath + '/'
            }));
            this.app.use(function () {
                var _ref = (0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee(ctx) {
                    return _regenerator2.default.wrap(function _callee$(_context) {
                        while (1) {
                            switch (_context.prev = _context.next) {
                                case 0:
                                    ctx.body = 'resource not found';

                                case 1:
                                case 'end':
                                    return _context.stop();
                            }
                        }
                    }, _callee, _this);
                }));

                return function (_x) {
                    return _ref.apply(this, arguments);
                };
            }());
        }
    }, {
        key: 'start',
        value: function start() {
            this.app.listen(this.options.port);
            console.log(_chalk2.default.yellow('[cabin] server start at port:' + this.options.port));
            console.log(_chalk2.default.yellow('[cabin] server start at path:' + this.options.staticPath));
        }
    }, {
        key: 'stop',
        value: function stop() {
            this.app.stop();
            console.log(_chalk2.default.yellow('[cabin] server stopped'));
        }
    }]);
    return CabinDevServer;
}();

exports.CabinDevServer = CabinDevServer;
